# -*- coding: utf-8 -*-
"""
    zebe.config.db
    ~~~~~~~~~~~~~~~~

    常量配置

    :copyright: (c) 2018 by Zebe.
    :license: BSD, see LICENSE for more details.
"""

MAIL_SMTP_PORT = 465
MAIL_SMTP_HOST = "smtp.qq.com"
MAIL_SENDER = 'zebe-notify@qq.com'
MAIL_PASSWORD = 'nramfouoyhkcdfjh'
MAIL_RECEIVER_ZEBE = 'zebe@vip.qq.com'
MAIL_RECEIVER_JULY = '1239571962@qq.com'
